package packageForLT06;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.event.MouseListener;

public interface DotView {

	/**
	 * This method renders the graphics of this view.
	 * 
	 * The method is invoked any time the view is repainted. This method will
	 * cause all of the widgets contain within it to be rendered (according to
	 * that widget's paintComponent(Graphics) method.
	 */
	public abstract void paintComponent(Graphics g);

	public abstract Dimension getPreferredSize();

	/**
	 * <p>
	 * Method that changes this view in response to any change in the data
	 * model. If the data model changes, the view repaints itself anew.
	 * <p/>
	 * 
	 * <p>
	 * This method is invoked to signal to this listener that the model (upon
	 * which this listener has been installed) has been changed. This provides
	 * an opportunity for the listener to something in response to any change to
	 * the model.
	 * </p>
	 * 
	 * <p>
	 * <b>Who invokes this method?</b> Think of who has been given access to
	 * this view... The documentation for the constructor specifies that this
	 * view has been installed upon the specified data model. So the data model
	 * is able to invoke this method within its inner workings.
	 * </p>
	 */
	public abstract void changed();

	public abstract boolean isInTopRegion(Point point);
	
	public abstract void addMouseListener(MouseListener l);


}